@@ -139,15 +139,15 @@ class theTVDB(object):
     try:
       logger.debug('Trying to open the url {url}...'.format(url=url))
       series_tree = get_xml_tree(url).find('Series')
-    except theTVDBAPIConnectionError as error:
-      raise theTVDBAPIError('Could not connect to theTVDB. {error_text}'.format(error_text=error))
+    except theTVDBConnectionError as error:
+      raise theTVDBError('Could not connect to theTVDB. {error_text}'.format(error_text=error))
       return
-    except theTVDBAPIXMLError as error:
-      raise theTVDBAPIError('There was an error with the XML retrieved from thetvdb.com. {error_text}'.format(error_text=error))
+    except theTVDBXMLError as error:
+      raise theTVDBError('There was an error with the XML retrieved from thetvdb.com. {error_text}'.format(error_text=error))
       return
     
     if series_tree is None:
-      raise theTVDBAPIError('This series does not exists at thetvdb.com.')
+      raise theTVDBError('This series does not exists at thetvdb.com.')
     
     #Set the series infos
     series_infos = dict()
